## What

Brief description of the change.

## Why

What problem does this solve?

## Testing

- [ ] New tests added
- [ ] `uv run pytest` passes
- [ ] `uv run mypy src/ --strict` passes
- [ ] `uv run ruff check src/ tests/` passes
